pub struct OutlineBuilder { /* private fields */ }Expand description
Accumulates Bézier path rendering commands into an Outline structure.
Implementations
Sourceimpl OutlineBuilder
impl OutlineBuilder
Sourcepub fn new() -> OutlineBuilder
pub fn new() -> OutlineBuilder
Creates a new empty OutlineBuilder.
Sourcepub fn into_outline(self) -> Outline
pub fn into_outline(self) -> Outline
Consumes this outline builder and returns the resulting outline.
Sourcepub fn take_outline(&mut self) -> Outline
pub fn take_outline(&mut self) -> Outline
Resets the outline builder and returns the old outline.